@@ -1,8 +1,5 @@
-## Load an example data
-data("AlphaPart.ped")
-
 ## Partition additive genetic values
-res <- AlphaPart(x=AlphaPart.ped, colPath="loc", colAGV=c("agv1", "agv2"))
+res <- AlphaPart(x=AlphaPart.ped, colPath="country", colBV=c("bv1", "bv2"))
 
 ## Write summary on the disk and collect saved file names
 fileName <- file.path(tempdir(), "AlphaPart")
